import click

from rsrch import download_papers, push_papers


@click.group()
def cli():
    pass


@cli.command()
def download():
    download_papers()


@cli.command()
@click.argument("arxiv_urls", nargs=-1)
def push(arxiv_urls):
    push_papers(arxiv_urls)


if __name__ == "__main__":
    cli()



from ._src.rsrch import download_papers, push_papers

# Make the functions accessible with from rsrch import *
__all__ = ["download_papers", "push_papers"]

# Make the functions directly accessible under the package namespace
download_papers = download_papers
push_papers = push_papers
